(function($) {
    function updatePreview($field) {
        var $variationField = $field.find('.acf-variation-select input:checked');
        var $modeField = $field.find('.acf-mode-select input:checked');
        var $preview = $field.find('.acf-preview');

        if ($variationField.length && $modeField.length) {
            var variation = $variationField.val();
            var mode = $modeField.val();
            var variations = $field.data('variations');
            var themeDir = themeData.themeDir;
            var previewImage = variations[variation] ? variations[variation][mode] : '';
            if (previewImage) {
                previewImage = themeDir + previewImage;
                $preview.html('<img src="' + previewImage + '" alt="' + variation + ' ' + mode + ' preview" />');
            } else {
                $preview.html('<p>Image preview not available</p>');
            }
        } else {
            $preview.html('');
        }
    }

    function toggleModeField($field) {
        var $variationCheckboxes = $field.find('.acf-variation-select input[type="checkbox"]');
        var $modeSelect = $field.find('.acf-mode-select');

        if ($variationCheckboxes.filter(':checked').length) {
            $modeSelect.show();
        } else {
            $modeSelect.hide();
        }
    }

    function updateHiddenFields($field) {
        var $variationCheckboxes = $field.find('.acf-variation-select input[type="checkbox"]');
        var $modeCheckboxes = $field.find('.acf-mode-select input[type="checkbox"]');

        var variationValue = $variationCheckboxes.filter(':checked').val() || '';
        var modeValue = $modeCheckboxes.filter(':checked').val() || '';

        if (!modeValue) {
            variationValue = ''; // Clear variation if mode is not checked
        }

        $field.find('input[type="hidden"][name*="[variation]"]').val(variationValue);
        $field.find('input[type="hidden"][name*="[mode]"]').val(modeValue);
    }

    function updateVersionVisibility($field) {
        var $variationCheckboxes = $field.find('.acf-variation-select input[type="checkbox"]');
        var variationValue = $variationCheckboxes.filter(':checked').val() || '';
        // Hide all fields with acf-field class that have a data-version attribute
        $field.parents('.layout').find('.acf-field[data-version]').hide();
        // Show fields with the specific variationValue
        $field.parents('.layout').find('.acf-field[data-version*="' + variationValue + '"]').show();
    }
    $(document).on('change', '.acf-variation-select input[type="checkbox"], .acf-mode-select input[type="checkbox"]', function() {
        var $field = $(this).closest('.acf-field-variation-mode');
        var $variationCheckboxes = $field.find('.acf-variation-select input[type="checkbox"]');
        var $modeCheckboxes = $field.find('.acf-mode-select input[type="checkbox"]');
        
        if ($(this).closest('.acf-variation-select').length) {
            if ($(this).prop('checked')) {
                $variationCheckboxes.not(this).prop('checked', false);
            } else {
                $modeCheckboxes.prop('checked', false);
            }
        } else {
            if ($(this).prop('checked')) {
                $modeCheckboxes.not(this).prop('checked', false);
            }
        }

        toggleModeField($field);
        updateHiddenFields($field);
        updatePreview($field);
        updateVersionVisibility($field);
      
    });

    $(document).ready(function() {
        $('.acf-field-variation-mode').each(function() {
            toggleModeField($(this));
            updateHiddenFields($(this));
            updateVersionVisibility($(this));
        });
    });
})(jQuery);
